part of masamune_firebase_messaging;

@immutable
class FirebaseMessagingAdapter
    extends MessagingAdapter<FirebaseMessagingModel> {
  const FirebaseMessagingAdapter({
    required this.serverKey,
    this.androidNotificationChannelId = "masamune_firebase_messaging_channel",
    this.androidNotificationChannelTitle = "Important Notification",
    this.androidNotificationChannelDescription =
        "This notification channel is used for important notifications.",
  });

  final String serverKey;
  final String androidNotificationChannelId;
  final String androidNotificationChannelTitle;
  final String androidNotificationChannelDescription;

  @override
  Future<void> initialize(
    BuildContext context, {
    List<void Function(FirebaseMessagingModel messaging)> callback = const [],
    List<String> subscribe = const [],
  }) async {
    await FirebaseMessagingCore.initialize(
      context,
      serverKey: serverKey,
      androidNotificationChannelDescription:
          androidNotificationChannelDescription,
      androidNotificationChannelId: androidNotificationChannelId,
      androidNotificationChannelTitle: androidNotificationChannelTitle,
      subscribe: subscribe,
      callback: callback,
    );
  }

  @override
  void listen(void Function(FirebaseMessagingModel messaging) callback) {
    FirebaseMessagingCore.listen(callback);
  }

  @override
  void unlisten(void Function(FirebaseMessagingModel messaging) callback) {
    FirebaseMessagingCore.unlisten(callback);
  }

  @override
  Future<void> send(
      {required String title,
      required String text,
      required String topic,
      DynamicMap? data}) async {
    await FirebaseMessagingCore.send(
      title: title,
      text: text,
      topic: topic,
      data: data,
    );
  }

  @override
  void subscribe(String topic) {
    FirebaseMessagingCore.subscribe(topic);
  }

  @override
  void unsubscribe(String topic) {
    FirebaseMessagingCore.unsubscribe(topic);
  }
}
